@@ -99,7 +99,7 @@ class JunOSDriver:
         try:
             self.device.open(auto_probe=self.auto_probe)
         except (ConnectTimeoutError, ProbeError) as cte:
-            pass
+            raise Exception(cte.msg)
         self.device.timeout = self.timeout
         self.device._conn._session.transport.set_keepalive(self.keepalive)
         if hasattr(self.device, "cu"):
@@ -107,6 +107,8 @@ class JunOSDriver:
             # ValueError: requested attribute name cu already exists
             del self.device.cu
         self.device.bind(cu=Config)
+        if not self.lock_disable and self.session_config_lock:
+            self._lock()
 
     def close(self):
         """Close the connection."""
@@ -275,12 +277,12 @@ class JunOSDriver:
 
         return result
 
-    def junos_compare(self, commands: List[str] = [''], check = False):
+    def junos_compare(self, commands: List[str] = [''], check = False, format: str='set'):
         diff = ''
         check_result = False
         config_set = '\n'.join(commands)
         with Config(self.device, mode='private') as cu: # config exclusive
-            cu.load(config_set, format="set", merge=True) # load config
+            cu.load(config_set, format=format, merge=True) # load config
             diff = cu.diff(0) # show | compare 
             if check:
                 check_result = cu.commit_check() # commit check
@@ -291,13 +293,13 @@ class JunOSDriver:
             'check': check_result,
         }
 
-    def junos_commit(self, mode: str = 'exclusive', commands: List[str] = [''], commit_comments: str = '', comfirm: int = 1):
+    def junos_commit(self, mode: str = 'exclusive', commands: List[str] = [''], format: str='set', commit_comments: str = '', comfirm: int = 1):
         config_set = '\n'.join(commands)
         diff = ''
         committed = False
         try:
             with Config(self.device, mode=mode) as cu: # config exclusive
-                cu.load(config_set, format="set", merge=True) # load config
+                cu.load(config_set, format=format, merge=True) # load config
                 cu.commit_check() # commit check
                 diff = cu.diff(0) # show | compare 
                 committed = cu.commit(confirm=comfirm, comment=commit_comments) # commit confirm 1 comment
